@@ -23,7 +23,6 @@ from os import listdir, lstat, stat, strerror
 from os.path import join, islink
 from stat import S_IFDIR, S_IFLNK, S_IFREG
 import collections
-import os
 import sys
 
 try:
@@ -41,7 +40,7 @@ if _scandir is None and ctypes is None:
     warnings.warn("scandir can't find the compiled _scandir C module "
                   "or ctypes, using slow generic fallback")
 
-__version__ = '1.5'
+__version__ = '1.8'
 __all__ = ['scandir', 'walk']
 
 # Windows FILE_ATTRIBUTE constants for interpreting the
@@ -96,6 +95,10 @@ class GenericDirEntry(object):
                 self._lstat = lstat(self.path)
             return self._lstat
 
+    # The code duplication below is intentional: this is for slightly
+    # better performance on systems that fall back to GenericDirEntry.
+    # It avoids an additional attribute lookup and method call, which
+    # are relatively slow on CPython.
     def is_dir(self, follow_symlinks=True):
         try:
             st = self.stat(follow_symlinks=follow_symlinks)
@@ -386,13 +389,17 @@ if sys.platform == 'win32':
 
     if _scandir is not None:
         scandir_c = _scandir.scandir
+        DirEntry_c = _scandir.DirEntry
 
     if _scandir is not None:
         scandir = scandir_c
+        DirEntry = DirEntry_c
     elif ctypes is not None:
         scandir = scandir_python
+        DirEntry = Win32DirEntryPython
     else:
         scandir = scandir_generic
+        DirEntry = GenericDirEntry
 
 
 # Linux, OS X, and BSD implementation
@@ -564,18 +571,23 @@ elif sys.platform.startswith(('linux', 'darwin', 'sunos5')) or 'bsd' in sys.plat
 
     if _scandir is not None:
         scandir_c = _scandir.scandir
+        DirEntry_c = _scandir.DirEntry
 
     if _scandir is not None:
         scandir = scandir_c
+        DirEntry = DirEntry_c
     elif ctypes is not None:
         scandir = scandir_python
+        DirEntry = PosixDirEntry
     else:
         scandir = scandir_generic
+        DirEntry = GenericDirEntry
 
 
 # Some other system -- no d_type or stat information
 else:
     scandir = scandir_generic
+    DirEntry = GenericDirEntry
 
 
 def _walk(top, topdown=True, onerror=None, followlinks=False):
